@@ -362,15 +362,14 @@ class Workspace(LanguageServerProtocolPart, HasExtendCapabilities):
                             )
                         ]
                     ),
-                    list,
+                    List[Any],
                 )
 
-                return r[0] if r is not None else None
+                return r[0] if r else None
             except asyncio.CancelledError:
                 raise
             except JsonRPCErrorException as e:
                 self._logger.warning(str(e))
-                pass
 
         result = self.settings
         for sub_key in str(section).split("."):
