@@ -39,18 +39,15 @@ from robotcode.core.lsp.types import (
     Range,
     TextEdit,
 )
-from robotcode.language_server.common.decorators import language_id, trigger_characters
-from robotcode.language_server.common.text_document import TextDocument
-from robotcode.language_server.robotframework.configuration import CompletionConfig
-from robotcode.language_server.robotframework.diagnostics.entities import VariableDefinitionType
-from robotcode.language_server.robotframework.diagnostics.library_doc import (
-    CompleteResultKind,
-    KeywordArgumentKind,
-    KeywordDoc,
-    KeywordMatcher,
-)
-from robotcode.language_server.robotframework.diagnostics.namespace import DocumentType, Namespace
-from robotcode.language_server.robotframework.utils.ast_utils import (
+
+from ...common.decorators import language_id, trigger_characters
+from ...common.text_document import TextDocument
+from ..configuration import CompletionConfig
+from ..diagnostics.entities import VariableDefinitionType
+from ..diagnostics.library_doc import CompleteResultKind, KeywordArgumentKind, KeywordDoc, KeywordMatcher
+from ..diagnostics.model_helper import ModelHelperMixin
+from ..diagnostics.namespace import DocumentType, Namespace
+from ..utils.ast_utils import (
     HasTokens,
     Token,
     get_nodes_at_position,
@@ -60,13 +57,11 @@ from robotcode.language_server.robotframework.utils.ast_utils import (
     whitespace_at_begin_of_token,
     whitespace_from_begin_of_token,
 )
-from robotcode.language_server.robotframework.utils.version import get_robot_version
-
-from .model_helper import ModelHelperMixin
+from ..utils.version import get_robot_version
 from .protocol_part import RobotLanguageServerProtocolPart
 
 if TYPE_CHECKING:
-    from robotcode.language_server.robotframework.protocol import RobotLanguageServerProtocol
+    from ..protocol import RobotLanguageServerProtocol
 
 
 DEFAULT_HEADER_STYLE = "*** {name}s ***"
@@ -152,6 +147,7 @@ _CompleteMethod = Callable[
 ]
 
 HEADERS = ["Test Case", "Setting", "Variable", "Keyword", "Comment", "Task"]
+RESOURCE_HEADERS = ["Setting", "Variable", "Keyword", "Comment"]
 
 
 __snippets: Optional[Dict[str, List[str]]] = None
@@ -398,8 +394,13 @@ class CompletionCollector(ModelHelperMixin):
         return completion_item
 
     async def create_headers_completion_items(self, range: Optional[Range]) -> List[CompletionItem]:
+        doc_type = await self.parent.documents_cache.get_document_type(self.document)
+
         if self.namespace.languages is None:
-            headers: Iterable[str] = HEADERS
+            if doc_type in [DocumentType.RESOURCE, DocumentType.INIT]:
+                headers: Iterable[str] = RESOURCE_HEADERS
+            else:
+                headers = HEADERS
         else:
             languages = self.namespace.languages.languages
 
@@ -410,7 +411,19 @@ class CompletionCollector(ModelHelperMixin):
             ):
                 languages = [v for v in languages if v.code != "en"]
 
-            headers = set(itertools.chain(*(lang.headers.keys() for lang in languages)))
+            headers = set(
+                itertools.chain(
+                    *(
+                        [
+                            k
+                            for k, v in lang.headers.items()
+                            if doc_type not in [DocumentType.RESOURCE, DocumentType.INIT]
+                            or v not in ("Test Cases", "Tasks")
+                        ]
+                        for lang in languages
+                    )
+                )
+            )
 
         return [
             CompletionItem(
@@ -702,6 +715,10 @@ class CompletionCollector(ModelHelperMixin):
             if not has_bdd and token is not None:
                 token = old_token
 
+        namespace_name = None
+        namespace_matcher = None
+        valid_namespace = False
+
         if token is not None:
             r = range_from_token(token)
 
@@ -719,18 +736,21 @@ class CompletionCollector(ModelHelperMixin):
                         lib_name_index = e
 
                 if lib_name_index >= 0:
-                    library_name = token.value[0 : lib_name_index - r.start.character]
+                    namespace_name = token.value[0 : lib_name_index - r.start.character]
 
                     libraries = await self.namespace.get_libraries()
 
-                    library_name_matcher = KeywordMatcher(library_name)
-                    library_name = next(
-                        (e for e in libraries.keys() if library_name_matcher == KeywordMatcher(e)), library_name
+                    namespace_matcher = KeywordMatcher(namespace_name, is_namespace=True)
+                    namespace_name = next(
+                        (e for e in libraries.keys() if namespace_matcher == KeywordMatcher(e, is_namespace=True)),
+                        namespace_name,
                     )
 
-                    if library_name in libraries:
+                    if namespace_name in libraries:
+                        valid_namespace = True
+
                         r.start.character = lib_name_index + 1
-                        for kw in libraries[library_name].library_doc.keywords.values():
+                        for kw in libraries[namespace_name].library_doc.keywords.values():
                             if kw.is_error_handler:
                                 continue
                             result.append(
@@ -739,7 +759,7 @@ class CompletionCollector(ModelHelperMixin):
                                     kind=CompletionItemKind.FUNCTION,
                                     detail=f"{CompleteResultKind.KEYWORD.value} "
                                     f"{f'({kw.libname})' if kw.libname is not None else ''}",
-                                    sort_text=f"020_{kw.name}",
+                                    sort_text=f"019_{kw.name}",
                                     insert_text_format=InsertTextFormat.PLAIN_TEXT
                                     if not kw.is_embedded
                                     else InsertTextFormat.SNIPPET,
@@ -765,10 +785,11 @@ class CompletionCollector(ModelHelperMixin):
                     resources = {
                         k: v
                         for k, v in (await self.namespace.get_resources()).items()
-                        if library_name_matcher == KeywordMatcher(v.name)
+                        if namespace_matcher == KeywordMatcher(v.name, is_namespace=True)
                     }
 
                     if resources:
+                        valid_namespace = True
                         r.start.character = lib_name_index + 1
                         for res in resources.values():
                             for kw in res.library_doc.keywords.values():
@@ -781,7 +802,7 @@ class CompletionCollector(ModelHelperMixin):
                                         kind=CompletionItemKind.FUNCTION,
                                         detail=f"{CompleteResultKind.KEYWORD.value} "
                                         f"{f'({kw.libname})' if kw.libname is not None else ''}",
-                                        sort_text=f"020_{kw.name}",
+                                        sort_text=f"019_{kw.name}",
                                         insert_text_format=InsertTextFormat.PLAIN_TEXT
                                         if not kw.is_embedded
                                         else InsertTextFormat.SNIPPET,
@@ -802,14 +823,24 @@ class CompletionCollector(ModelHelperMixin):
                                     )
                                 )
 
-                    return result
+        if token is not None:
+            r = range_from_token(token)
 
         if r is None:
             r = Range(position, position)
 
+        if namespace_matcher is not None:
+            namespace_matcher = KeywordMatcher(namespace_matcher.name)
+
         for kw in await self.namespace.get_keywords():
             if kw.is_error_handler:
                 continue
+            if (
+                valid_namespace
+                and namespace_matcher is not None
+                and not kw.matcher.normalized_name.startswith(namespace_matcher.normalized_name)
+            ):
+                continue
 
             result.append(
                 CompletionItem(
@@ -834,6 +865,9 @@ class CompletionCollector(ModelHelperMixin):
                 )
             )
 
+        if valid_namespace and namespace_matcher is not None:
+            return result
+
         for k, v in (await self.namespace.get_libraries()).items():
             result.append(
                 CompletionItem(
